==> nocc-1.8.3.tbz: www/nocc/lang/no.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: no.php 2181 2010-04-27 09:07:03Z gerundt $
 */

/** Norwegian (bokmål)‬ (‪Norsk (bokmål)‬)
 *
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Nghtwlkr
 * @author Rune Dalmo <runed@balder.narviknett.no>
 * @author Simny
 */

$lang_locale = 'no_NO.UTF-8';
$default_date_format = '%d.%m.%y';
$no_locale_date_format = '%d.%m.%y';
$default_time_format = '%I:%M %p';
$err_user_empty = 'Brukernavn er ikke spesifisert';
$err_passwd_empty = 'Passord er ikke spesifisert';
$alt_delete = 'Slett alle markerte meldinger';
$alt_delete_one = 'Slett markert melding';
$alt_new_msg = 'Nye meldinger';
$alt_reply = 'Svar til avsenderen';
$alt_reply_all = 'Svar til alle';
$alt_forward = 'Videresend';
$alt_next = 'Neste';
$alt_prev = 'Forrige';
$title_next_page = 'Neste side';
$title_prev_page = 'Forrige side';
$title_next_msg = 'Neste melding';
$title_prev_msg = 'Forrige melding';
$html_theme_label = 'Tema:';
$html_welcome = 'Velkommen til %1$s';
$html_login = 'Logg inn';
$html_user_label = 'Bruker:';
$html_passwd_label = 'Passord:';
$html_submit = 'Logg inn';
$html_help = 'Hjelp';
$html_server_label = 'Tjener:';
$html_wrong = 'Brukernavn eller passord er feil';
$html_retry = 'Prøv igjen';
$html_remember = 'Husk innstillinger';
$html_lang_label = 'Språk:';
$html_msgperpage_label = 'Meldinger per side:';
$html_preferences = 'Innstillinger';
$html_full_name_label = 'Fullt navn:';
$html_email_address_label = 'E-postadresse:';
$html_ccself = 'Kopi til megselv';
$html_hide_addresses = 'Skjul adresser';
$html_outlook_quoting = 'Outlook-liknende sitering';
$html_reply_to = 'Svar til';
$html_use_signature = 'Bruk signatur';
$html_signature = 'Signatur';
$html_signature_label = 'Signatur:';
$html_reply_leadin_label = 'Svarinnledning:';
$html_prefs_updated = 'Innstillinger oppdatert';
$html_manage_folders_link = 'Ordne IMAP-mapper';
$html_manage_filters_link = 'Administrer E-postfiltere';
$html_use_graphical_smilies = 'Bruk grafiske smilefjes';
$html_sent_folder_label = 'Kopier sendt e-post til en bestemt mappe:';
$html_trash_folder_label = 'Flytt slettet e-post til en bestemt mappe:';
$html_colored_quotes = 'Fargede sitat';
$html_display_struct = 'Vis strukturert tekst';
$html_send_html_mail = 'Send e-post i HTML-format';
$html_folders = 'Mapper';
$html_folders_create_failed = 'Kunne ikke lage mappe!';
$html_folders_sub_failed = 'Kunne ikke abonnere på mappe!';
$html_folders_unsub_failed = 'Kunne ikke slutte å abonnere på mappe!';
$html_folders_rename_failed = 'Kunne ikke gi nytt navn til mappa!';
$html_folders_updated = 'Mapper oppdatert';
$html_folder_subscribe = 'Abonner på';
$html_folder_rename = 'Gi nytt navn';
$html_folder_create = 'Lag en ny mappe med navnet';
$html_folder_remove = 'Slutt å abonnere på';
$html_folder_delete = 'Slett';
$html_folder_to = 'til';
$html_filter_remove = 'Slett';
$html_filter_body = 'Meldingstekst';
$html_filter_subject = 'Meldingstema';
$html_filter_to = 'Til-felt';
$html_filter_cc = 'Kopi-felt';
$html_filter_from = 'Fra-felt';
$html_filter_change_tip = 'For å endre et filter kan du bare overskrive det.';
$html_reapply_filters = 'Gjenninnfør alle filtre';
$html_filter_contains = 'Inneholder';
$html_filter_name = 'Filternavn';
$html_filter_action = 'Filterhandling';
$html_filter_moveto = 'Flytt til';
$html_select_one = '--Velg en--';
$html_and = 'Og';
$html_new_msg_in = 'Nye meldinger i';
$html_or = 'eller';
$html_move = 'Flytt';
$html_copy = 'Kopier';
$html_messages_to = 'valgte meldinger til';
$html_gotopage = 'Gå til side';
$html_gotofolder = 'Gå til mappe';
$html_other_folders = 'Mappeliste';
$html_page = 'Side';
$html_of = 'av';
$html_view_header = 'Vis overskrift';
$html_remove_header = 'Skjul overskrift';
$html_inbox = 'Innboks';
$html_new_msg = 'Skriv';
$html_reply = 'Svar';
$html_reply_short = 'Sv:';
$html_reply_all = 'Svar til alle';
$html_forward = 'Videresend';
$html_forward_short = 'Vs:';
$html_forward_info = 'Den videresendte meldingen vil bli sendt som et vedlegg til denne.';
$html_delete = 'Slett';
$html_new = 'Ny';
$html_mark = 'Slett';
$html_att_label = 'Vedlegg:';
$html_atts_label = 'Vedlegg:';
$html_unknown = '[ukjent]';
$html_attach = 'Legg til';
$html_attach_forget = 'Du må legge til filen før du kan sende meldingen !';
$html_attach_delete = 'Fjern markerte vedlegg';
$html_attach_none = 'Du må velge en fil å legge til!';
$html_sort_by = 'Sorter etter';
$html_sort = 'Sorter';
$html_from = 'Fra';
$html_from_label = 'Fra:';
$html_subject = 'Emne';
$html_subject_label = 'Emne:';
$html_date = 'Dato';
$html_date_label = 'Dato:';
$html_sent_label = 'Sendt:';
$html_wrote = 'skrev';
$html_size = 'Størrelse';
$html_totalsize = 'Total Størrelse';
$html_kb = 'kB';
$html_mb = 'MB';
$html_gb = 'GB';
$html_bytes = 'byte';
$html_filename = 'Filnavn';
$html_to = 'Til';
$html_to_label = 'Til:';
$html_cc = 'Kopi';
$html_cc_label = 'Kopi:';
$html_bcc_label = 'Blind kopi:';
$html_nosubject = 'Intet emne';
$html_send = 'Send';
$html_cancel = 'Avbryt';
$html_no_mail = 'Ingen meldinger';
$html_logout = 'Logg av';
$html_msg = 'Melding';
$html_msgs = 'Meldinger';
$html_configuration = 'Denne tjeneren er ikke riktig satt opp!';
$html_priority = 'Prioritet';
$html_priority_label = 'Prioritet:';
$html_lowest = 'Lavest';
$html_low = 'Lav';
$html_normal = 'Normal';
$html_high = 'Høy';
$html_highest = 'Høyest';
$html_flagged = 'Merket';
$html_spam = 'Søppel';
$html_spam_warning = 'Denne melding har blitt klassifisert som søppel.';
$html_receipt = 'Krev en leveringsbekreftelse';
$html_select = 'Velg';
$html_select_all = 'Inverter valg';
$html_select_contacts = 'Velg kontakter';
$html_loading_image = 'Laster bilde';
$html_send_confirmed = 'Din e-post ble akseptert for levering';
$html_no_sendaction = 'Ingen handling spesifisert. Prøv å aktivere JavaScript.';
$html_error_occurred = 'En feil oppstod';
$html_prefs_file_error = 'Ikke mulig å åpne innstillingsfilen for skriving (lagring).';
$html_wrap = 'Antall tegn som utgående meldinger skal brytes til:';
$html_wrap_none = 'Ingen bryting';
$html_usenet_separator = 'Usenet-separator («-- \n») før signatur';
$html_mark_as = 'Marker som';
$html_read = 'lest';
$html_unread = 'ulest';
$html_encoding_label = 'Tegnkoding:';
$html_add = 'Legg til';
$html_contacts = '%1$s kontakter';
$html_modify = 'Endre';
$html_back = 'Tilbake';
$html_contact_add = 'Legg til en ny kontakt';
$html_contact_mod = 'Endre en kontakt';
$html_contact_first = 'Fornavn';
$html_contact_last = 'Etternavn';
$html_contact_nick = 'Kallenavn';
$html_contact_mail = 'E-post';
$html_contact_list = 'Kontaktlisten til %1$s';
$html_contact_del = 'fra kontaktlisten';
$html_contact_count = '%1$d kontakter';
$html_contact_err1 = 'Maksimum antall kontakter er «%1$d»';
$html_contact_err2 = 'Du kan ikke legge til en ny kontakt';
$html_contact_err3 = 'Du har ikke tilgangsrettigheter til kontaktlisten';
$html_contact_none = 'Fant ingen kontakter.';
$html_del_msg = 'Slett valgte meldinger?';
$html_down_mail = 'Last ned';
$original_msg = '-- Opprinnelig melding --';
$to_empty = '\'Til\'-feltet kan ikke være tomt!';
$html_images_warning = 'Av sikkerhetshensyn vises ikke eksterne bilder.';
$html_images_display = 'Vis bilder';
$html_smtp_error_no_conn = 'Ikke mulig å oppnå forbindelse';
$html_smtp_error_unexpected = 'Uventet svar:';
$lang_could_not_connect = 'Kunne ikke oppnå tilkobling mot server';
$lang_invalid_msg_num = 'Ugyldig meldingsnummer';
$html_file_upload_attack = 'Muligens filopplastingsangrep';
$html_invalid_email_address = 'Ugyldig e-postadresse';
$html_invalid_msg_per_page = 'Ugyldig antall meldinger per side';
$html_invalid_wrap_msg = 'Ugyldig bredde på meldingsbryting';
$html_seperate_msg_win = 'Meldinger i egne vindu';
$html_err_file_contacts = 'Kan ikke åpne kontaktfilen for skriving.';
$html_session_file_error = 'Kan ikke åpne sesjonsfilen for skriving.';
$html_login_not_allowed = 'Denne innloggingen har ikke tillatelse for oppkobling.';
$lang_err_send_delay = 'Du må vente mellom to e-poster (%1$d sekunder)';
$html_search = 'Søk';

==> nocc-1.9.1.tbz: www/nocc/lang/no.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: no.php 2376 2011-01-22 19:46:26Z gerundt $
 */
/** Norwegian (bokmål)‬ (‪Norsk (bokmål)‬)
 * 
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Nghtwlkr
 * @author Rune Dalmo <runed@balder.narviknett.no>
 * @author Simny
 */

$lang_locale = 'no_NO.UTF-8';
$default_date_format = '%d.%m.%y';
$no_locale_date_format = '%d.%m.%y';
$default_time_format = '%I:%M %p';
$err_user_empty = 'Brukernavn er ikke spesifisert';
$err_passwd_empty = 'Passord er ikke spesifisert';
$alt_delete = 'Slett alle markerte meldinger';
$alt_delete_one = 'Slett markert melding';
$alt_new_msg = 'Nye meldinger';
$alt_reply = 'Svar til avsenderen';
$alt_reply_all = 'Svar til alle';
$alt_forward = 'Videresend';
$alt_next = 'Neste';
$alt_prev = 'Forrige';
$title_next_page = 'Neste side';
$title_prev_page = 'Forrige side';
$title_next_msg = 'Neste melding';
$title_prev_msg = 'Forrige melding';
$html_theme_label = 'Tema:';
$html_welcome = 'Velkommen til %1$s';
$html_login = 'Logg inn';
$html_user_label = 'Bruker:';
$html_passwd_label = 'Passord:';
$html_submit = 'Logg inn';
$html_help = 'Hjelp';
$html_server_label = 'Tjener:';
$html_wrong = 'Brukernavn eller passord er feil';
$html_retry = 'Prøv igjen';
$html_remember = 'Husk innstillinger';
$html_lang_label = 'Språk:';
$html_msgperpage_label = 'Meldinger per side:';
$html_preferences = 'Innstillinger';
$html_full_name_label = 'Fullt navn:';
$html_email_address_label = 'E-postadresse:';
$html_bccself = 'Bcc self';
$html_hide_addresses = 'Skjul adresser';
$html_outlook_quoting = 'Outlook-liknende sitering';
$html_reply_to = 'Svar til';
$html_use_signature = 'Bruk signatur';
$html_signature = 'Signatur';
$html_signature_label = 'Signatur:';
$html_reply_leadin_label = 'Svarinnledning:';
$html_prefs_updated = 'Innstillinger oppdatert';
$html_manage_folders_link = 'Ordne IMAP-mapper';
$html_manage_filters_link = 'Administrer E-postfiltere';
$html_use_graphical_smilies = 'Bruk grafiske smilefjes';
$html_sent_folder_label = 'Kopier sendt e-post til en bestemt mappe:';
$html_trash_folder_label = 'Flytt slettet e-post til en bestemt mappe:';
$html_colored_quotes = 'Fargede sitat';
$html_display_struct = 'Vis strukturert tekst';
$html_send_html_mail = 'Send e-post i HTML-format';
$html_folders = 'Mapper';
$html_folders_create_failed = 'Kunne ikke lage mappe!';
$html_folders_sub_failed = 'Kunne ikke abonnere på mappe!';
$html_folders_unsub_failed = 'Kunne ikke slutte å abonnere på mappe!';
$html_folders_rename_failed = 'Kunne ikke gi nytt navn til mappa!';
$html_folders_updated = 'Mapper oppdatert';
$html_folder_subscribe = 'Abonner på';
$html_folder_rename = 'Gi nytt navn';
$html_folder_create = 'Lag en ny mappe med navnet';
$html_folder_remove = 'Slutt å abonnere på';
$html_folder_delete = 'Slett';
$html_folder_to = 'til';
$html_filter_remove = 'Slett';
$html_filter_body = 'Meldingstekst';
$html_filter_subject = 'Meldingstema';
$html_filter_to = 'Til-felt';
$html_filter_cc = 'Kopi-felt';
$html_filter_from = 'Fra-felt';
$html_filter_change_tip = 'For å endre et filter kan du bare overskrive det.';
$html_reapply_filters = 'Gjenninnfør alle filtre';
$html_filter_contains = 'Inneholder';
$html_filter_name = 'Filternavn';
$html_filter_action = 'Filterhandling';
$html_filter_moveto = 'Flytt til';
$html_select_one = '--Velg en--';
$html_and = 'Og';
$html_new_msg_in = 'Nye meldinger i';
$html_or = 'eller';
$html_move = 'Flytt';
$html_copy = 'Kopier';
$html_messages_to = 'valgte meldinger til';
$html_gotopage = 'Gå til side';
$html_gotofolder = 'Gå til mappe';
$html_other_folders = 'Mappeliste';
$html_page = 'Side';
$html_of = 'av';
$html_view_header = 'Vis overskrift';
$html_remove_header = 'Skjul overskrift';
$html_inbox = 'Innboks';
$html_new_msg = 'Skriv';
$html_reply = 'Svar';
$html_reply_short = 'Sv:';
$html_reply_all = 'Svar til alle';
$html_forward = 'Videresend';
$html_forward_short = 'Vs:';
$html_forward_info = 'Den videresendte meldingen vil bli sendt som et vedlegg til denne.';
$html_delete = 'Slett';
$html_new = 'Ny';
$html_mark = 'Slett';
$html_att_label = 'Vedlegg:';
$html_atts_label = 'Vedlegg:';
$html_unknown = '[ukjent]';
$html_part_x = 'Del %s';
$html_attach = 'Legg til';
$html_attach_forget = 'Du må legge til filen før du kan sende meldingen !';
$html_attach_delete = 'Fjern markerte vedlegg';
$html_attach_none = 'Du må velge en fil å legge til!';
$html_sort_by = 'Sorter etter';
$html_sort = 'Sorter';
$html_from = 'Fra';
$html_from_label = 'Fra:';
$html_subject = 'Emne';
$html_subject_label = 'Emne:';
$html_date = 'Dato';
$html_date_label = 'Dato:';
$html_sent_label = 'Sendt:';
$html_wrote = 'skrev';
$html_size = 'Størrelse';
$html_totalsize = 'Total Størrelse';
$html_kb = 'kB';
$html_mb = 'MB';
$html_gb = 'GB';
$html_bytes = 'byte';
$html_filename = 'Filnavn';
$html_to = 'Til';
$html_to_label = 'Til:';
$html_cc = 'Kopi';
$html_cc_label = 'Kopi:';
$html_bcc_label = 'Blind kopi:';
$html_nosubject = 'Intet emne';
$html_send = 'Send';
$html_cancel = 'Avbryt';
$html_no_mail = 'Ingen meldinger';
$html_logout = 'Logg ut';
$html_msg = 'Melding';
$html_msgs = 'Meldinger';
$html_configuration = 'Denne tjeneren er ikke riktig satt opp!';
$html_priority = 'Prioritet';
$html_priority_label = 'Prioritet:';
$html_lowest = 'Lavest';
$html_low = 'Lav';
$html_normal = 'Normal';
$html_high = 'Høy';
$html_highest = 'Høyest';
$html_flagged = 'Merket';
$html_spam = 'Søppel';
$html_spam_warning = 'Denne melding har blitt klassifisert som søppel.';
$html_receipt = 'Krev en leveringsbekreftelse';
$html_select = 'Velg';
$html_select_all = 'Inverter valg';
$html_select_contacts = 'Velg kontakter';
$html_loading_image = 'Laster bilde';
$html_send_confirmed = 'Din e-post ble akseptert for levering';
$html_no_sendaction = 'Ingen handling spesifisert. Prøv å aktivere JavaScript.';
$html_error_occurred = 'En feil oppstod';
$html_prefs_file_error = 'Ikke mulig å åpne innstillingsfilen for skriving (lagring).';
$html_wrap = 'Antall tegn som utgående meldinger skal brytes til:';
$html_wrap_none = 'Ingen bryting';
$html_usenet_separator = 'Usenet-separator («-- \n») før signatur';
$html_mark_as = 'Marker som';
$html_read = 'lest';
$html_unread = 'ulest';
$html_encoding_label = 'Tegnkoding:';
$html_add = 'Legg til';
$html_contacts = '%1$s kontakter';
$html_modify = 'Endre';
$html_back = 'Tilbake';
$html_contact_add = 'Legg til en ny kontakt';
$html_contact_mod = 'Endre en kontakt';
$html_contact_first = 'Fornavn';
$html_contact_last = 'Etternavn';
$html_contact_nick = 'Kallenavn';
$html_contact_mail = 'E-post';
$html_contact_list = 'Kontaktlisten til %1$s';
$html_contact_del = 'fra kontaktlisten';
$html_contact_count = '%1$d kontakter';
$html_contact_err1 = 'Maksimum antall kontakter er «%1$d»';
$html_contact_err2 = 'Du kan ikke legge til en ny kontakt';
$html_contact_err3 = 'Du har ikke tilgangsrettigheter til kontaktlisten';
$html_contact_none = 'Fant ingen kontakter.';
$html_del_msg = 'Slett valgte meldinger?';
$html_down_mail = 'Last ned';
$original_msg = '-- Opprinnelig melding --';
$to_empty = '\'Til\'-feltet kan ikke være tomt!';
$html_images_warning = 'Av sikkerhetshensyn vises ikke eksterne bilder.';
$html_images_display = 'Vis bilder';
$html_smtp_error_no_conn = 'Ikke mulig å oppnå forbindelse';
$html_smtp_error_unexpected = 'Uventet svar:';
$lang_could_not_connect = 'Kunne ikke oppnå tilkobling mot server';
$lang_invalid_msg_num = 'Ugyldig meldingsnummer';
$html_file_upload_attack = 'Muligens filopplastingsangrep';
$html_invalid_email_address = 'Ugyldig e-postadresse';
$html_invalid_msg_per_page = 'Ugyldig antall meldinger per side';
$html_invalid_wrap_msg = 'Ugyldig bredde på meldingsbryting';
$html_seperate_msg_win = 'Meldinger i egne vindu';
$html_err_file_contacts = 'Kan ikke åpne kontaktfilen for skriving.';
$html_session_file_error = 'Kan ikke åpne sesjonsfilen for skriving.';
$html_login_not_allowed = 'Denne innloggingen har ikke tillatelse for oppkobling.';
$lang_err_send_delay = 'Du må vente mellom to e-poster (%1$d sekunder)';
$html_search = 'Søk';
